@@ -16,7 +16,7 @@ kConfig2FileMap = {
 }
 
 
-kSearchAlgorithms = ['hyperopt', 'skopt', 'bohb', 'ax', 'tune', 'random', 'grid', 'bayesian']
+kSearchAlgorithms = ['hyperopt', 'skopt', 'bohb', 'ax', 'tune', 'random', 'grid', 'bayesian', 'nevergrad']
 kSchedulers = ['asynchyperband', 'bohbhyperband', 'pbt']
 kMetricMode = ['min', 'max']
 
